@@ -36,6 +36,7 @@ pub(crate) struct Config {
   pub(crate) shell_args: Option<Vec<String>>,
   pub(crate) shell_command: bool,
   pub(crate) subcommand: Subcommand,
+  pub(crate) tempdir: Option<PathBuf>,
   pub(crate) timestamp: bool,
   pub(crate) timestamp_format: String,
   pub(crate) unsorted: bool,
@@ -116,6 +117,7 @@ mod arg {
   pub(crate) const SHELL: &str = "SHELL";
   pub(crate) const SHELL_ARG: &str = "SHELL-ARG";
   pub(crate) const SHELL_COMMAND: &str = "SHELL-COMMAND";
+  pub(crate) const TEMPDIR: &str = "TEMPDIR";
   pub(crate) const TIMESTAMP: &str = "TIMESTAMP";
   pub(crate) const TIMESTAMP_FORMAT: &str = "TIMESTAMP-FORMAT";
   pub(crate) const UNSORTED: &str = "UNSORTED";
@@ -289,7 +291,7 @@ impl Config {
           .env("JUST_LIST_SUBMODULES")
           .help("List recipes in submodules")
           .action(ArgAction::SetTrue)
-          .env("JUST_LIST_SUBMODULES"),
+          .requires(cmd::LIST),
       )
       .arg(
         Arg::new(arg::NO_ALIASES)
@@ -373,6 +375,14 @@ impl Config {
           .action(ArgAction::SetTrue)
           .help("Invoke <COMMAND> with the shell used to run recipe lines and backticks"),
       )
+      .arg(
+        Arg::new(arg::TEMPDIR)
+          .action(ArgAction::Set)
+          .env("JUST_TEMPDIR")
+          .long("tempdir")
+          .value_parser(value_parser!(PathBuf))
+          .help("Save temporary files to <TEMPDIR>."),
+      )
       .arg(
         Arg::new(arg::TIMESTAMP)
           .action(ArgAction::SetTrue)
@@ -524,10 +534,10 @@ impl Config {
           .short('l')
           .long("list")
           .num_args(0..)
-          .value_name("PATH")
+          .value_name("MODULE")
           .action(ArgAction::Set)
           .conflicts_with(arg::ARGUMENTS)
-          .help("List available recipes")
+          .help("List available recipes in <MODULE> or root if omitted")
           .help_heading(cmd::HEADING),
       )
       .arg(
@@ -792,6 +802,7 @@ impl Config {
       },
       shell_command: matches.get_flag(arg::SHELL_COMMAND),
       subcommand,
+      tempdir: matches.get_one::<PathBuf>(arg::TEMPDIR).map(Into::into),
       timestamp: matches.get_flag(arg::TIMESTAMP),
       timestamp_format: matches
         .get_one::<String>(arg::TIMESTAMP_FORMAT)
