@@ -42,8 +42,6 @@ pub(crate) use {
     fragment::Fragment,
     function::Function,
     interpreter::Interpreter,
-    interrupt_guard::InterruptGuard,
-    interrupt_handler::InterruptHandler,
     item::Item,
     justfile::Justfile,
     keyed::Keyed,
@@ -57,7 +55,6 @@ pub(crate) use {
     name::Name,
     namepath::Namepath,
     ordinal::Ordinal,
-    output::output,
     output_error::OutputError,
     parameter::Parameter,
     parameter_kind::ParameterKind,
@@ -80,6 +77,8 @@ pub(crate) use {
     settings::Settings,
     shebang::Shebang,
     show_whitespace::ShowWhitespace,
+    signal::Signal,
+    signal_handler::SignalHandler,
     source::Source,
     string_delimiter::StringDelimiter,
     string_kind::StringKind,
@@ -106,6 +105,7 @@ pub(crate) use {
   lexiclean::Lexiclean,
   libc::EXIT_FAILURE,
   once_cell::sync::Lazy,
+  rand::seq::IndexedRandom,
   regex::Regex,
   serde::{
     ser::{SerializeMap, SerializeSeq},
@@ -133,13 +133,16 @@ pub(crate) use {
     vec,
   },
   strum::{Display, EnumDiscriminants, EnumString, IntoStaticStr},
-  tempfile::tempfile,
+  tempfile::{tempfile, TempDir},
   typed_arena::Arena,
   unicode_width::{UnicodeWidthChar, UnicodeWidthStr},
 };
 
 #[cfg(test)]
-pub(crate) use crate::{node::Node, tree::Tree};
+pub(crate) use {
+  crate::{node::Node, tree::Tree},
+  std::slice,
+};
 
 pub use crate::run::run;
 
@@ -148,7 +151,7 @@ use request::Request;
 
 // Used in integration tests.
 #[doc(hidden)]
-pub use {request::Response, unindent::unindent};
+pub use {request::Response, subcommand::INIT_JUSTFILE, unindent::unindent};
 
 type CompileResult<'a, T = ()> = Result<T, CompileError<'a>>;
 type ConfigResult<T> = Result<T, ConfigError>;
@@ -217,8 +220,6 @@ mod expression;
 mod fragment;
 mod function;
 mod interpreter;
-mod interrupt_guard;
-mod interrupt_handler;
 mod item;
 mod justfile;
 mod keyed;
@@ -232,7 +233,6 @@ mod module_path;
 mod name;
 mod namepath;
 mod ordinal;
-mod output;
 mod output_error;
 mod parameter;
 mod parameter_kind;
@@ -256,6 +256,10 @@ mod setting;
 mod settings;
 mod shebang;
 mod show_whitespace;
+mod signal;
+mod signal_handler;
+#[cfg(unix)]
+mod signals;
 mod source;
 mod string_delimiter;
 mod string_kind;
